triggerTextStyle property
Style of the selected value text shown in the trigger (single-select).
Implementation
final TextStyle? triggerTextStyle;
Style of the selected value text shown in the trigger (single-select).
final TextStyle? triggerTextStyle;