MultiSelectDropdown class

Multi-select searchable dropdown without BLoC/Cubit.

Pass items and isLoading from your own state. When onSearch is non-null, it is called on each query while online; otherwise the list is filtered locally against the cached full list from items.

Inheritance

Constructors

MultiSelectDropdown({required String hintText, required List<DropdownItem> items, required bool isLoading, Key? key, List<DropdownItem> selectedItems = const [], void onSelectionChanged(List<DropdownItem> items)?, void onSearch(String query)?, String? searchHint, String? noResultsText, String? loadingText, bool needInitialFetch = false, int maxDisplayChips = 2, DropdownPlusTheme? dropdownTheme, DropdownPlusThemeStyle? themeStyle, Widget itemBuilder(DropdownItem item, bool isSelected)?, Widget selectedItemBuilder(List<DropdownItem> selected)?, double? buttonHeight, double? buttonWidth, Future<bool> checkInternetConnection()?})
const

Properties

buttonHeight double?
final
buttonWidth double?
final
checkInternetConnection Future<bool> Function()?
final
final
hashCode int
The hash code for this object.
no setterinherited
hintText String
final
isLoading bool
final
itemBuilder Widget Function(DropdownItem item, bool isSelected)?
final
items List<DropdownItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingText String?
final
maxDisplayChips int
final
needInitialFetch bool
final
noResultsText String?
final
onSearch → void Function(String query)?
final
onSelectionChanged → void Function(List<DropdownItem> items)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String?
final
selectedItemBuilder Widget Function(List<DropdownItem> selected)?
final
selectedItems List<DropdownItem>
final
themeStyle DropdownPlusThemeStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MultiSelectDropdown>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited