checkInternetConnection property

Future<bool> Function()? checkInternetConnection
final

Optional async function returning true when the device is online. When null, the widget always performs remote search (no offline fallback).

checkInternetConnection: () async {
  final result = await Connectivity().checkConnectivity();
  return result != ConnectivityResult.none;
},

Implementation

final Future<bool> Function()? checkInternetConnection;