selectedValueBuilder property
Override how the selected value is displayed in the trigger button.
Implementation
final Widget Function(DropdownItem<dynamic> selectedItem)?
selectedValueBuilder;
Override how the selected value is displayed in the trigger button.
final Widget Function(DropdownItem<dynamic> selectedItem)?
selectedValueBuilder;