DropdownItem<T> class

A generic model representing a single item in a SearchableDropdownPlus or MultiSelectDropdownPlus dropdown list.

T is the type of the underlying data value (e.g., a User, String, int).

Example

final item = DropdownItem<User>(
  value: user,
  label: user.name,
);

Constructors

const

Properties

hashCode int
The hash code for this object.
no setteroverride
label String
The human-readable string displayed in the dropdown list and chips.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The underlying data object for this item.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override