DropdownPlusThemePresets class
Provides ready-made DropdownPlusTheme instances for each DropdownPlusThemeStyle.
Use forStyle to resolve a theme from an enum value. Useful when you want to apply a preset and then override a few properties:
dropdownTheme: DropdownPlusThemePresets.forStyle(DropdownPlusThemeStyle.dark)
.copyWith(borderRadius: 16),
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forStyle(
DropdownPlusThemeStyle style) → DropdownPlusTheme -
Returns the DropdownPlusTheme for the given
style.